@@ -46,8 +46,8 @@ static QString DRKONQI_REPORT_BUG_URL = KDE_BUGZILLA_URL + QStringLiteral("enter
 
 DrKonqiDialog::DrKonqiDialog(QWidget * parent) :
         QDialog(parent),
-        m_aboutBugReportingDialog(0),
-        m_backtraceWidget(0)
+        m_aboutBugReportingDialog(nullptr),
+        m_backtraceWidget(nullptr)
 {
     setAttribute(Qt::WA_DeleteOnClose, true);
 
